==> autopoi-2.0.0-sources.jar: org/jeecgframework/poi/entity/ImageEntity.java <==
package org.jeecgframework.poi.entity;

/**
 * word导出,图片设置和图片信息
 * 
 * @author liusq
 * @date  2022-5-27
 */
public class ImageEntity {

    public static String URL  = "url";
    public static String Data = "data";
    /**
     * 图片输入方式
     */
    private String       type = URL;
    /**
     * 图片宽度
     */
    private int          width;
    // 图片高度
    private int          height;
    // 图片地址
    private String       url;
    // 图片信息
    private byte[]       data;

    private int          rowspan = 1;
    private int          colspan = 1;


    public ImageEntity() {

    }

    public ImageEntity(byte[] data, int width, int height) {
        this.data = data;
        this.width = width;
        this.height = height;
        this.type = Data;
    }

    public ImageEntity(String url, int width, int height) {
        this.url = url;
        this.width = width;
        this.height = height;
    }

    public byte[] getData() {
        return data;
    }

    public int getHeight() {
        return height;
    }

    public String getType() {
        return type;
    }

    public String getUrl() {
        return url;
    }

    public int getWidth() {
        return width;
    }

    public void setData(byte[] data) {
        this.data = data;
    }

    public void setHeight(int height) {
        this.height = height;
    }

    public void setType(String type) {
        this.type = type;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public void setWidth(int width) {
        this.width = width;
    }

    public int getRowspan() {
        return rowspan;
    }

    public void setRowspan(int rowspan) {
        this.rowspan = rowspan;
    }

    public int getColspan() {
        return colspan;
    }

    public void setColspan(int colspan) {
        this.colspan = colspan;
    }
}

==> autopoi-2.0.4-sources.jar: org/jeecgframework/poi/entity/ImageEntity.java <==
package org.jeecgframework.poi.entity;

import org.jeecgframework.poi.consts.ImageScaleMode;

/**
 * word导出,图片设置和图片信息
 * 
 * @author liusq
 * @date  2022-5-27
 */
public class ImageEntity {

    public static String URL  = "url";
    public static String Data = "data"; 
    
    /**
     * 图片输入方式
     */
    private String       type = URL;
    /**
     * 图片宽度
     */
    private int          width;
    // 图片高度
    private int          height;
    // 图片地址
    private String       url;
    // 图片信息
    private byte[]       data;

    private int          rowspan = 1;
    private int          colspan = 1;
    
    /**
     * 图片缩放模式枚举
     * for [issues/8892] AutoPoi ImageEntity建议添加scale属性，控制图片导出缩放模式
     */
    private ImageScaleMode scaleModeEnum = ImageScaleMode.STRETCH;


    public ImageEntity() {

    }

    public ImageEntity(byte[] data, int width, int height) {
        this.data = data;
        this.width = width;
        this.height = height;
        this.type = Data;
    }

    public ImageEntity(String url, int width, int height) {
        this.url = url;
        this.width = width;
        this.height = height;
    }

    public byte[] getData() {
        return data;
    }

    public int getHeight() {
        return height;
    }

    public String getType() {
        return type;
    }

    public String getUrl() {
        return url;
    }

    public int getWidth() {
        return width;
    }

    public void setData(byte[] data) {
        this.data = data;
    }

    public void setHeight(int height) {
        this.height = height;
    }

    public void setType(String type) {
        this.type = type;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public void setWidth(int width) {
        this.width = width;
    }

    public int getRowspan() {
        return rowspan;
    }

    public void setRowspan(int rowspan) {
        this.rowspan = rowspan;
    }

    public int getColspan() {
        return colspan;
    }

    public void setColspan(int colspan) {
        this.colspan = colspan;
    }

    /**
     * 获取图片缩放模式
     * @deprecated 使用 {@link #getScaleModeEnum()} 代替
     * @return 缩放模式代码值
     */
    @Deprecated
    public int getScaleMode() {
        return scaleModeEnum.getCode();
    }

    /**
     * 设置图片缩放模式
     * @deprecated 使用 {@link #setScaleModeEnum(ImageScaleMode)} 代替
     * @param scaleMode 缩放模式代码值
     */
    @Deprecated
    public void setScaleMode(int scaleMode) {
        this.scaleModeEnum = ImageScaleMode.valueOf(scaleMode);
    }
    
    /**
     * 获取图片缩放模式枚举
     * @return 缩放模式枚举
     */
    public ImageScaleMode getScaleModeEnum() {
        return scaleModeEnum;
    }
    
    /**
     * 设置图片缩放模式枚举
     * @param scaleModeEnum 缩放模式枚举
     */
    public void setScaleModeEnum(ImageScaleMode scaleModeEnum) {
        this.scaleModeEnum = scaleModeEnum;
    }
}
